flagVisiumOutliers() marks six Visium array positions that have shown
systematically low library sizes across multiple datasets. It accepts either
a SpatialExperiment or Seurat object and adds a logical
systematic_outliers column to its metadata.
Arguments
- spe
A
SpatialExperimentorSeuratobject containing Visium array coordinates.SpatialExperimentinputs must containarray_rowandarray_colmetadata columns. Seurat inputs may contain the same columns or expose them through a Visium image.- image_id
For Seurat inputs, the image containing Visium array coordinates. The first image is used when
NULL.
Examples
spe <- STexampleData::Visium_humanDLPFC()
#>
#> see ?STexampleData and browseVignettes('STexampleData') for documentation
#> downloading 1 resources
#> retrieving 1 resource
#>
#> loading from cache
spe <- flagVisiumOutliers(spe)
spe <- spe[, !spe$systematic_outliers]